;***************************************************
; globals
;***************************************************

	sr 	= 44100
	ksmps 	= 20
	nchnls 	= 2
	0dbfs 	= 32768


;***************************************************
;ftables
;***************************************************

	giSine		ftgen	0, 0, 65536, 10, 1	; sine
	giSample1	ftgen   0, 0, 0, 1, "samples/BlueVibMed_Ab3.wav",  0,  0,  0
	giSample1_orig	= 415.293

;***************************************************
; simple sine wave instrument
;***************************************************
	instr 1

; score parameters
	iamp		= ampdbfs(p4)
	iNote		= p5
	icps		= 440 * semitone(iNote-69)	; cps from midi note number
	ipan		= p6
	irevbSend	= p7

; envelope
	iAttack		= 0.01
	iDecay		= 0.3
	iSustain 	= 0.6
	iRelease 	= 0.3
	amp		adsr	iAttack, iDecay, iSustain, iRelease

; audio generator
	a1		oscil	amp, icps, giSine

; master amp and panning
	aLeft	= a1 * iamp * (1-ipan)
	aRight	= a1 * iamp * ipan

; send to master audio out
	chnmix	aLeft,	"MasterAudioLeft"
	chnmix	aRight,	"MasterAudioRight"

; effect send
	chnmix	aLeft * irevbSend,	"ReverbSendLeft"
	chnmix	aRight * irevbSend,	"ReverbSendRight"

	endin
;***************************************************

;***************************************************
; sample player instrument
;***************************************************
	instr 2

; score parameters
	iamp		= ampdbfs(p4)
	iNote		= p5
	icps		= 440 * semitone(iNote-69)	; cps from midi note number
	ipan		= p6
	irevbSend	= p7

; envelope
	iAttack		= 0.01
	iDecay		= 0.3
	iSustain 	= 0.6
	iRelease 	= 0.3
	amp		adsr	iAttack, iDecay, iSustain, iRelease

; audio generator
	a1		loscil	amp, icps, giSample1, giSample1_orig

; master amp and panning
	aLeft	= a1 * iamp * (1-ipan)
	aRight	= a1 * iamp * ipan

; send to master audio out
	chnmix	aLeft,	"MasterAudioLeft"
	chnmix	aRight,	"MasterAudioRight"

; effect send
	chnmix	aLeft * irevbSend,	"ReverbSendLeft"
	chnmix	aRight * irevbSend,	"ReverbSendRight"

	endin
;***************************************************


;***************************************************
; simple reverb
;***************************************************
	instr 98

; audio input
	ainL		chnget	"ReverbSendLeft"
	ainR		chnget	"ReverbSendRight"
	inLevel		= 0.25
	ainL		= ainL * inLevel
	ainR		= ainR * inLevel

; reverb effect
	kfblvl		= 0.85
	kfco		= 7000
	aLeft, aRight 	reverbsc ainL, ainR, kfblvl, kfco

; send to master for recording to file
	chnmix	aLeft,	"MasterAudioLeft"
	chnmix	aRight,	"MasterAudioRight"

; clear chn channels used for mixing 
	chnclear	"ReverbSendLeft"
	chnclear	"ReverbSendRight"

	endin
;***************************************************

;***************************************************
; master audio out
;***************************************************
	instr 99

; audio input
	aLeft		chnget	"MasterAudioLeft"
	aRight		chnget	"MasterAudioRight"
	iMasterLevel	= 1.0
	aLeft		= aLeft * iMasterLevel
	aRight		= aRight * iMasterLevel

; audio output
	outs	aLeft, aRight

; send audio to recording instrument
	chnset	aLeft,	"RecordAudioLeft"
	chnset	aRight,	"RecordAudioRight"


; clear chn channels used for mixing 
	chnclear	"MasterAudioLeft"
	chnclear	"MasterAudioRight"

	endin
;***************************************************

;***************************************************
; recording to file
;***************************************************
	instr 100

; audio input
	a1		chnget	"RecordAudioLeft"
	a2		chnget	"RecordAudioRight"

; write to file
	Sname	strget p4
	chnset	Sname, "recordFileName"
	iFormat = 14 ; 16bit wav
	fout	Sname, iFormat, a1, a2

	endin

;***************************************************
; close audio file (audio write to disk)
;***************************************************
	instr 101
	Sname	chnget	"recordFileName"
	ficlose	Sname
	endin
;***************************************************

